package com.caimei365.user.controller;

import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.MobileDto;
import com.caimei365.user.model.dto.PasswordDto;
import com.caimei365.user.service.BaseService;
import io.swagger.annotations.*;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * 用户公共API
 *
 * @author : Charles
 * @date : 2021/3/4
 */
@Api(tags = "用户公共API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/user")
public class BaseApi {

    private final BaseService baseService;
    @Value(value = "${swagger.enabled}")
    private Boolean swaggerEnabled;

    @GetMapping("")
    public String welcome() {
        if (swaggerEnabled) {
            return "欢迎使用！<br><a href='http://47.119.112.46:18011/doc.html'>doc接口文档入口(beta)</a><br><a href='http://47.119.112.46:18011/swagger-ui/index.html'>swagger接口文档入口(beta)</a>";
        }
        return "欢迎使用！";
    }

    /**
     * 获取图片验证码
     * <p>
     * spi旧接口：/user/getImgVerifyCode
     *
     * @param platformType 0:www，1:crm/h5，2:小程序
     */
    @ApiOperation("获取图片验证码")
    @ApiImplicitParam(required = true, name = "platformType", value = "0:www，1:crm/h5，2:小程序")
    @GetMapping("/captcha")
    public ResponseJson<Map<String, Object>> getCaptchaImage(Integer platformType) {
        return baseService.getCaptchaImage(platformType);
    }

    /**
     * 获取短信验证码
     * <p>
     * spi旧接口：/user/activateCodeByReg
     *
     * @param mobile           手机号
     * @param activateCodeType 1:找回密码,2:注册机构,3:供应商注册,4:修改手机号-旧手机验证码,5:修改手机号-新手机验证码
     * @param platformType     0:www，1:crm/h5，2:小程序
     * @param isCheckCaptcha   是否检查图片验证码，0:检查，1:不检查
     * @param imgCode          图片验证码
     * @param token            图片验证码token
     */
    @ApiOperation("获取短信验证码")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "mobile", value = "手机号"),
            @ApiImplicitParam(required = true, name = "activateCodeType", value = "1:找回密码,2:注册机构,3:供应商注册,4:更换联系人手机号-旧手机验证码,5:更换联系人手机号-新手机验证码"),
            @ApiImplicitParam(required = false, name = "platformType", value = "0:www，1:crm/h5，2:小程序"),
            @ApiImplicitParam(required = false, name = "isCheckCaptcha", value = "是否检查图片验证码，0:检查，1:不检查"),
            @ApiImplicitParam(required = false, name = "imgCode", value = "图片验证码"),
            @ApiImplicitParam(required = false, name = "token", value = "图片token")

    })
    @GetMapping("/sms/code")
    public ResponseJson getSmsCode(String mobile, Integer activateCodeType, Integer platformType, Integer isCheckCaptcha, String imgCode, String token) {
        return baseService.getSmsCode(mobile, activateCodeType, platformType, isCheckCaptcha, imgCode, token);
    }

    /**
     * 绑定账号,发送短信验证
     * <p>
     * spi旧接口：/user/note
     *
     * @param mobile         运营人员手机号
     * @param bindMobile     机构手机号
     * @param userId         机构Id
     * @param platformType   0:www，1:crm/h5，2:小程序
     * @param isCheckCaptcha 是否检查图片验证码，0:检查，1:不检查
     * @param imgCode        图片验证码
     * @param token          图片验证码token
     */
    @ApiOperation("绑定账号,发送短信验证")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "mobile", value = "运营人员手机号"),
            @ApiImplicitParam(required = false, name = "bindMobile", value = "机构手机号"),
            @ApiImplicitParam(required = false, name = "userId", value = "机构Id"),
            @ApiImplicitParam(required = false, name = "platformType", value = "0:www，1:crm/h5，2:小程序"),
            @ApiImplicitParam(required = false, name = "isCheckCaptcha", value = "是否检查图片验证码，0:检查，1:不检查"),
            @ApiImplicitParam(required = false, name = "imgCode", value = "图片验证码"),
            @ApiImplicitParam(required = false, name = "token", value = "图片token")
    })
    @GetMapping("/sms/bind")
    public ResponseJson getBindSmsCode(String mobile, String bindMobile, Integer userId, Integer platformType, Integer isCheckCaptcha, String imgCode, String token) {
        return baseService.getBindSmsCode(mobile, bindMobile, userId, platformType, isCheckCaptcha, imgCode, token);
    }


    /**
     * 获取邮箱验证码
     *
     * @param email  邮箱
     * @param status 1:绑定邮箱,2邮箱注册,3邮箱找回秘密
     */
    @ApiOperation("获取邮箱验证码（旧：/user/mailbox）")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "email", value = "邮箱"),
            @ApiImplicitParam(required = true, name = "status", value = "1:绑定邮箱,2邮箱注册,3邮箱找回秘密")
    })
    @GetMapping("/mail/code")
    public ResponseJson sendMail(String email, Integer status) {
        return baseService.getEmailCode(email, status);
    }

    /**
     * 修改密码（找回密码）
     *
     * @param passwordDto {
     *                    mobileOrEmail 手机号或邮箱
     *                    smsCode       短信验证码(旧：activationCode)
     *                    password      密码
     *                    confirmPwd    确认密码
     *                    status        1:手机号找回,2:邮箱找回
     *                    }
     */
    @ApiOperation("修改密码（旧：/user/findCompanyPwd）")
    @PostMapping("/update/password")
    public ResponseJson updatePassword(PasswordDto passwordDto) {
        return baseService.updatePassword(passwordDto);
    }

    /**
     * 更换联系人手机号
     *
     * @param mobileDto {
     *                  mobile          旧手机号(contractMobile)
     *                  smsCode         旧手机短信验证码(mobileCode)
     *                  newMobile       新手机号(contractMobile2)
     *                  newSmsCode      新手机短信验证码(mobileCode)
     *                  userId          用户Id
     *                  }
     */
    @ApiOperation("更换联系人手机号（旧：/club/changeMobile）")
    @PostMapping("/update/mobile")
    public ResponseJson changeMobile(MobileDto mobileDto) {
        return baseService.updateMobile(mobileDto);
    }

    @ApiOperation("超级会员购买记录接口")
    @GetMapping("super/history")
    public ResponseJson findVipHistory(Integer userId,
                                       @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                       @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize) {
        return baseService.findVipHistory(userId, pageNum, pageSize);
    }

    @ApiOperation("超级会员会员中心")
    @GetMapping("super/center")
    public ResponseJson<Map<String, Object>> superCenter(Integer userId) {
        return baseService.superCenter(userId);
    }
}
