package com.caimei365.user.service.impl;

import com.caimei365.user.components.RedisService;
import com.caimei365.user.mapper.BaseMapper;
import com.caimei365.user.mapper.ShopMapper;
import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.ShopUpdateDto;
import com.caimei365.user.model.po.ShopCertPo;
import com.caimei365.user.model.po.UserPo;
import com.caimei365.user.model.vo.*;
import com.caimei365.user.service.ShopService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/9
 */
@Slf4j
@Service
public class ShopServiceImpl implements ShopService {

    @Resource
    private RedisService redisService;
    @Resource
    private BaseMapper baseMapper;
    @Resource
    private ShopMapper shopMapper;


    /**
     * 根据用户Id查询供应商资料
     *
     * @param userId 用户Id
     *
     * @return Map(userPo,clubPo)
     */
    @Override
    public ResponseJson<Map<String, Object>> getShopUserInfo(Integer userId) {
        if (null == userId) {
            return ResponseJson.error("参数异常：用户Id不能为空！", null);
        }
        // 用户信息
        UserVo user = baseMapper.getUserByUserId(userId);
        if (user == null) {
            return ResponseJson.error("用户信息不存在", null);
        }
        if (!StringUtils.isBlank(user.getAuditNote()) && 2 == user.getAuditStatus()) {
            if (user.getAuditNote().contains(",")) {
                List<String> list = Arrays.asList(user.getAuditNote().split(","));
                user.setAuditNoteList(list);
            } else {
                user.setAuditNoteList(Collections.singletonList(user.getAuditStatus().toString()));
            }
        }
        // 供应商信息
        ShopVo shop = shopMapper.getShopById(user.getShopId());
        if (shop == null) {
            return ResponseJson.error("供应商信息不存在", null);
        }
        if (null != shop.getTownId()) {
            TownVo town = baseMapper.getTown(shop.getTownId());
            CityVo city = baseMapper.getCity(town.getCityId());
            ProvinceVo province = baseMapper.getProvince(city.getProvinceId());
            shop.setCityId(city.getCityId());
            shop.setProvinceId(province.getProvinceId());
            shop.setProvincialAddress(province.getName() + "" + city.getName() + "" + town.getName());
        }
        // 荣誉证书
        List<String> honorCertification = shopMapper.getShopCert(user.getShopId(), 1);
        shop.setHonorCertification(honorCertification);
        // 生产经营证书
        List<String> operationLicence = shopMapper.getShopCert(user.getShopId(), 2);
        if (null != operationLicence && operationLicence.size() > 0) {
            shop.setOperationLicence(operationLicence.get(0));
        }
        // 产品证书
        List<String> productCertification = shopMapper.getShopCert(user.getShopId(), 3);
        shop.setProductCertification(productCertification);
        // 卫生许可证
        List<String> hygienicLicense = shopMapper.getShopCert(user.getShopId(), 5);
        if (null != hygienicLicense && hygienicLicense.size() > 0) {
            shop.setHygienicLicense(hygienicLicense.get(0));
        }
        // 税务登记证
        List<String> taxLicense = shopMapper.getShopCert(user.getShopId(), 6);
        if (null != taxLicense && taxLicense.size() > 0) {
            shop.setTaxLicense(taxLicense.get(0));
        }
        HashMap<String, Object> map = new HashMap(2);
        map.put("user", user);
        map.put("shop", shop);
        return ResponseJson.success(map);
    }


    /**
     * 修改供应商资料
     *
     * @param shopUpdateDto ShopUpdateDto{
     *                        shopId                    供应商Id
     *                        userId                    用户Id
     *                        name                      组织名称
     *                        shortName                     供应商公司简称(shortName)
     *                        email                     邮箱
     *                        contractPhone             固定电话
     *                        linkMan                   联系人
     *                        provinceId                省(provinceID)
     *                        cityId                    市(cityID)
     *                        townId                    所在县区Id(townID)
     *                        address                   地址
     *                        socialCreditCode          统一社会信用代码(营业执照编号)
     *                        businessLicense           营业执照(businessLicenseImage)
     *                        firstShopType             医疗=1和非医疗=2
     *                        secondShopType            医疗的二级分类 一类器械=1、二类器械 =2、三类器械=3、其他=4 /// 1和非医疗没有二级分类
     *                        mainProduct               主打项目(mainpro)
     *                        mainProductDesc           主打商品说明(productDesc)
     *                        legalPerson               法人代表
     *                        registeredCapital         注册资本
     *                        faxNumber                 传真号(fax)
     *                        companyNature             传真号(nature)
     *                        turnover                  年营业额
     *                        medicalPracticeLicenseImg 医疗执业许可证(medicalPracticeLicenseImg1)
     *                        shopDesc                  公司介绍(info)
     *                        businessScope             经营范围
     *                        logo                      公司LOGO
     *                    }
     * @param operationLicence          生产经营证书(productionLicence)
     * @param hygienicLicense           卫生许可证
     * @param taxLicense                税务登记证
     * @param honorCertification        荣誉证书(certificateHonor)
     * @param productCertification      产品证书
     * @return ClubUpdateDto
     */
    @Override
    public ResponseJson updateShopUserInfo(ShopUpdateDto shopUpdateDto, String operationLicence, String hygienicLicense, String taxLicense, String honorCertification, String productCertification) {
        // 参数校验
        if (null == shopUpdateDto.getUserId()) {
            return ResponseJson.error("参数异常：用户Id不能为空！");
        }
        if (null == shopUpdateDto.getShopId()) {
            return ResponseJson.error("参数异常：供应商Id不能为空！");
        }
        if (StringUtils.isNotBlank(shopUpdateDto.getContractEmail())) {
            Integer userIdByEmail = baseMapper.getUserIdByEmail(shopUpdateDto.getContractEmail());
            if (null != userIdByEmail && !userIdByEmail.equals(shopUpdateDto.getUserId())) {
                return ResponseJson.error("该邮箱已被使用");
            }
        }
        /*
            组装用户数据 user
         */
        UserPo user = new UserPo();
        user.setUserId(shopUpdateDto.getUserId());
        user.setName(shopUpdateDto.getName());
        user.setUserName(shopUpdateDto.getShortName());
        user.setEmail(shopUpdateDto.getContractEmail());
        // 更新供应商用户信息
        shopMapper.updateShopUserByUpdateInfo(user);
        // 更新供应商信息
        shopMapper.updateShopByUpdateInfo(shopUpdateDto);
        if (StringUtils.isNotBlank(shopUpdateDto.getSocialCreditCode())) {
            // 清除数据库证书数据
            shopMapper.deleteShopCertByShopId(shopUpdateDto.getShopId());
            ShopCertPo shopCert = new ShopCertPo();
            shopCert.setShopId(shopUpdateDto.getShopId());
            shopCert.setShopCertTypeId(2);
            shopCert.setImage(operationLicence);
            shopCert.setName("生产经营证书");
            // 保存生产经营证书
            shopMapper.insertShopCert(shopCert);
            shopCert.setShopCertTypeId(5);
            shopCert.setImage(hygienicLicense);
            shopCert.setName("卫生许可证");
            // 保存卫生许可证
            shopMapper.insertShopCert(shopCert);
            shopCert.setShopCertTypeId(6);
            shopCert.setImage(taxLicense);
            shopCert.setName("税务登记证");
            // 保存税务登记证
            shopMapper.insertShopCert(shopCert);
            if (StringUtils.isNotBlank(honorCertification)) {
                String[] images = honorCertification.split(",");
                for (String image : images) {
                    if (StringUtils.isNotBlank(image)) {
                        shopCert.setShopCertTypeId(1);
                        shopCert.setImage(image);
                        shopCert.setName("荣誉证书");
                        // 保存荣誉证书
                        shopMapper.insertShopCert(shopCert);
                    }
                }
            }
            if (StringUtils.isNotBlank(productCertification)) {
                String[] images = productCertification.split(",");
                for (String image : images) {
                    if (StringUtils.isNotBlank(image)) {
                        shopCert.setShopCertTypeId(3);
                        shopCert.setImage(image);
                        shopCert.setName("产品证书");
                        // 保存产品证书
                        shopMapper.insertShopCert(shopCert);
                    }
                }
            }
        }
        return ResponseJson.success("修改供应商资料成功", null);
    }
}
